@@ -15,10 +15,8 @@ class Dialog : public QDialog
 public:
     explicit Dialog(QWidget *parent = 0);
     ~Dialog();
-    QString zipCode;
-    QString getZip(){
-        return zipCode;
-    }
+	QString* zipCode;
+	QString* getZip();
 
 public slots:
     void setZip();
