@@ -1,5 +1,6 @@
 #include "graphframe.h"
 #include <QApplication>
+#include "mainwindow.h"
 
 GraphFrame::GraphFrame(QString& title, QPixmap& graphPix){
 	layout = new QVBoxLayout();
@@ -14,7 +15,7 @@ GraphFrame::GraphFrame(QString& title, QPixmap& graphPix){
 
 	this->title = new QLabel(title);
 	this->title->setAutoFillBackground(true);
-	colorize(this->title);
+	MainWindow::colorize(this->title);
 
 	this->scrollArea = new QScrollArea();
 	scrollArea->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
@@ -39,15 +40,6 @@ QVBoxLayout* GraphFrame::getLayout(){
 	return layout;
 }
 
-void GraphFrame::colorize(QLabel *label){
-	label->setPalette(QApplication::palette().highlight().color());
-	QPalette pal = label->palette();
-
-	QLinearGradient linearGrad(QPointF(0, 0), QPointF(0, 35));
-	linearGrad.setColorAt(0, pal.color(QPalette::Highlight));
-	linearGrad.setColorAt(1, Qt::black);
-	QBrush brush(linearGrad);
-
-	pal.setBrush(QPalette::Window, brush);;
-	label->setPalette(pal);
+void GraphFrame::setPix(QPixmap &pix){
+	graph->setPixmap(pix);
 }
