@@ -8,7 +8,6 @@
 #include "stackedwindow.h"
 #include "settingsdialog.h"
 #include "dialog.h"
-#include "noaaparser.h"
 
 
 using namespace std;
@@ -90,10 +89,6 @@ void MainWindow::setSettings(){
 
     sd.exec();
     sd.deleteLater();
-
-	settings->setValue("home1", *sd.getHome1());
-	settings->setValue("home2", *sd.getHome2());
-	settings->setValue("default", *sd.getDefaultHome());
 }
 
 /**
@@ -109,7 +104,7 @@ MainWindow::~MainWindow()
   Launches the default browser. Loads the current city in the NAOO website
   */
 void MainWindow::visitNAOO(){
-	QString str("http://forecast.weather.gov/zipcity.php?inputstring=" + *zipCode);
+        QString str("http://forecast.weather.gov/zipcity.php?inputstring=" + *zipCode);
     QDesktopServices::openUrl(QUrl(str));
 }
 
@@ -173,7 +168,7 @@ void MainWindow::changeZip(QString* zip){
 	}
 
 	if(!zipCode->isEmpty()){
-		QString urlString("http://umcs.maine.edu/~naddeoa/?zipcode=" + *zipCode);
+                QString urlString("http://umcs.maine.edu/~naddeoa/qtweather/?zipcode=" + *zipCode); //TODO
 
 		QNetworkReply* zipReply = manager->get(QNetworkRequest(QUrl(urlString)));
 		connect(zipReply, SIGNAL(finished()), this, SLOT(gotXML()));
@@ -258,8 +253,8 @@ void MainWindow::gotXML(){
 		}
 
 		//add information to the current day (left pane)
-		QString zc("MEZ015");
-		QNetworkReply* tempGraphReply = manager->get(QNetworkRequest(QUrl( QUrl::fromPercentEncoding(days.at(0).namedItem("tempGraph").toElement().text().toStdString().c_str()) )));
+//		QString zc("MEZ015");
+		QNetworkReply* tempGraphReply = manager->get(QNetworkRequest(QUrl( QUrl::fromPercentEncoding(days.at(0).toElement().elementsByTagName("graph").at(0).toElement().text().toStdString().c_str()) )));
 		connect(tempGraphReply, SIGNAL(finished()), this, SLOT(setTempGraph()));
 		ui->forecastTemp->setText(days.at(0).namedItem("temp").toElement().text());
 		ui->forecastPrecip->setText("Precipitation: " + days.at(0).namedItem("precipitation").toElement().text());
