@@ -1,5 +1,6 @@
 #include "settingsdialog.h"
 #include "ui_settingsdialog.h"
+#include <QSettings>
 
 SettingsDialog::SettingsDialog(QVariant& home1, QVariant& home2, QVariant& defaultHome, QWidget *parent) :
     QDialog(parent),
@@ -12,14 +13,6 @@ SettingsDialog::SettingsDialog(QVariant& home1, QVariant& home2, QVariant& defau
     ui->home2Entry->setInputMethodHints((Qt::ImhDigitsOnly));
 	ui->activeComboBox->setCurrentIndex(defaultHome.toInt());
 
-	this->home1 = &home1;
-	this->home2 = &home2;
-	this->defaultHome = &defaultHome;
-
-//	this->home1 = new QVariant(home1);
-//	this->home2 = new QVariant(home2);
-//	this->defaultHome = new QVariant(defaultHome);
-
     connect(this, SIGNAL(accepted()), this, SLOT(setValues()));
 }
 
@@ -28,6 +21,7 @@ SettingsDialog::~SettingsDialog()
 	delete ui;
 }
 
+/** Relay the layouts when going between portrait and landscape */
 void SettingsDialog::resizeEvent(QResizeEvent *event){
 	if(event->oldSize().width() > event->size().width()){
 		ui->mainLayout->setDirection(QBoxLayout::TopToBottom);
@@ -36,20 +30,11 @@ void SettingsDialog::resizeEvent(QResizeEvent *event){
 	}
 }
 
+/** Write the new values to the settings flie*/
 void SettingsDialog::setValues(){
-    home1 = new QVariant(ui->home1Entry->text());
-    home2 = new QVariant(ui->home2Entry->text());
-    defaultHome = new QVariant(ui->activeComboBox->currentIndex());
-}
-
-QVariant* SettingsDialog::getHome1(){
-	return home1;
-}
-
-QVariant* SettingsDialog::getHome2(){
-	return home2;
-}
-
-QVariant* SettingsDialog::getDefaultHome(){
-	return defaultHome;
+	QSettings* settings = new QSettings("qtweather", "qtweather", this);
+	settings->setValue("home1", ui->home1Entry->text());
+	settings->setValue("home2", ui->home2Entry->text());
+	settings->setValue("default", ui->activeComboBox->currentIndex());
+	settings->deleteLater();
 }
