@@ -15,9 +15,6 @@ class SettingsDialog : public QDialog
 public:
 	explicit SettingsDialog(QVariant& home1, QVariant& home2, QVariant& defaultHome, QWidget *parent = 0);
     ~SettingsDialog();
-    QVariant* getHome1();
-    QVariant* getHome2();
-    QVariant* getDefaultHome();
 
 protected:
 	virtual void resizeEvent(QResizeEvent * event);
@@ -25,9 +22,6 @@ protected:
 
 private:
     Ui::SettingsDialog *ui;
-	QVariant* home1;
-	QVariant* home2;
-	QVariant* defaultHome;
 
 private slots:
     void setValues();
