@@ -30,19 +30,15 @@ protected:
     virtual void resizeEvent(QResizeEvent * event);
 
 private slots:
-    void setIcons(int mapping);
-	void addSnowGraph();
-	void addRainGraph();
+	void setIcons(int mapping);
 
 private:
     Ui::StackedWindow *ui;
+	GraphFrame** frames;
+	int frameLen;
     QSignalMapper* mapper;
 	QNetworkAccessManager *manager;
 	QDomDocument *doc;
-	GraphFrame* tempFrame;
-	GraphFrame* precipFrame;
-	GraphFrame* snowFrame;
-	GraphFrame* rainFrame;
 };
 
 #endif // STACKEDWINDOW_H
